pub(crate) struct InstrumentedFinishProvider<'a> {
pub(crate) inner: &'a dyn StateProvider,
pub(crate) metrics: TempoPayloadBuilderMetrics,
}Expand description
Wraps a [StateProvider] reference to instrument hashed_post_state and
state_root_with_updates with tracing spans and histogram metrics during builder.finish().
Fields
inner: &'a dyn StateProvidermetrics: TempoPayloadBuilderMetricsTrait Implementations
Sourceimpl<'a> AccountReader for InstrumentedFinishProvider<'_>
impl<'a> AccountReader for InstrumentedFinishProvider<'_>
Sourcefn basic_account(&self, address: &Address) -> ProviderResult<Option<Account>>
fn basic_account(&self, address: &Address) -> ProviderResult<Option<Account>>
Get basic account information. Read more
Sourceimpl<'a> AsRef<dyn StateProvider + 'a> for InstrumentedFinishProvider<'a>
impl<'a> AsRef<dyn StateProvider + 'a> for InstrumentedFinishProvider<'a>
Sourceimpl<'a> BlockHashReader for InstrumentedFinishProvider<'_>
impl<'a> BlockHashReader for InstrumentedFinishProvider<'_>
Sourcefn block_hash(&self, number: u64) -> ProviderResult<Option<B256>>
fn block_hash(&self, number: u64) -> ProviderResult<Option<B256>>
Get the hash of the block with the given number. Returns
None if no block with this number
exists.Sourcefn canonical_hashes_range(
&self,
start: BlockNumber,
end: BlockNumber,
) -> ProviderResult<Vec<B256>>
fn canonical_hashes_range( &self, start: BlockNumber, end: BlockNumber, ) -> ProviderResult<Vec<B256>>
Get headers in range of block hashes or numbers Read more
fn convert_block_hash(
&self,
hash_or_number: HashOrNumber,
) -> Result<Option<FixedBytes<32>>, ProviderError>
fn convert_block_hash( &self, hash_or_number: HashOrNumber, ) -> Result<Option<FixedBytes<32>>, ProviderError>
Get the hash of the block with the given number. Returns
None if no block with this number
exists.Sourceimpl<'a> BytecodeReader for InstrumentedFinishProvider<'_>
impl<'a> BytecodeReader for InstrumentedFinishProvider<'_>
Sourcefn bytecode_by_hash(&self, code_hash: &B256) -> ProviderResult<Option<Bytecode>>
fn bytecode_by_hash(&self, code_hash: &B256) -> ProviderResult<Option<Bytecode>>
Get account code by its hash
Sourceimpl HashedPostStateProvider for InstrumentedFinishProvider<'_>
impl HashedPostStateProvider for InstrumentedFinishProvider<'_>
Sourcefn hashed_post_state(&self, bundle_state: &BundleState) -> HashedPostState
fn hashed_post_state(&self, bundle_state: &BundleState) -> HashedPostState
Returns the
HashedPostState of the provided [BundleState].Sourceimpl<'a> StateProofProvider for InstrumentedFinishProvider<'_>
impl<'a> StateProofProvider for InstrumentedFinishProvider<'_>
Sourcefn proof(
&self,
input: TrieInput,
address: Address,
slots: &[B256],
) -> ProviderResult<AccountProof>
fn proof( &self, input: TrieInput, address: Address, slots: &[B256], ) -> ProviderResult<AccountProof>
Get account and storage proofs of target keys in the
HashedPostState
on top of the current state.Sourcefn multiproof(
&self,
input: TrieInput,
targets: MultiProofTargets,
) -> ProviderResult<MultiProof>
fn multiproof( &self, input: TrieInput, targets: MultiProofTargets, ) -> ProviderResult<MultiProof>
Generate [
MultiProof] for target hashed account and corresponding
hashed storage slot keys.Sourceimpl<'a> StateProvider for InstrumentedFinishProvider<'_>
impl<'a> StateProvider for InstrumentedFinishProvider<'_>
Sourcefn storage(
&self,
account: Address,
storage_key: StorageKey,
) -> ProviderResult<Option<StorageValue>>
fn storage( &self, account: Address, storage_key: StorageKey, ) -> ProviderResult<Option<StorageValue>>
Get storage of given account.
fn account_code(
&self,
addr: &Address,
) -> Result<Option<Bytecode>, ProviderError>
fn account_code( &self, addr: &Address, ) -> Result<Option<Bytecode>, ProviderError>
Get account code by its address. Read more
fn account_balance(
&self,
addr: &Address,
) -> Result<Option<Uint<256, 4>>, ProviderError>
fn account_balance( &self, addr: &Address, ) -> Result<Option<Uint<256, 4>>, ProviderError>
Get account balance by its address. Read more
Sourceimpl StateRootProvider for InstrumentedFinishProvider<'_>
impl StateRootProvider for InstrumentedFinishProvider<'_>
Sourcefn state_root(&self, hashed_state: HashedPostState) -> ProviderResult<B256>
fn state_root(&self, hashed_state: HashedPostState) -> ProviderResult<B256>
Returns the state root of the
BundleState on top of the current state. Read moreSourcefn state_root_from_nodes(&self, input: TrieInput) -> ProviderResult<B256>
fn state_root_from_nodes(&self, input: TrieInput) -> ProviderResult<B256>
Returns the state root of the
HashedPostState on top of the current state but reuses the
intermediate nodes to speed up the computation. It’s up to the caller to construct the
prefix sets and inform the provider of the trie paths that have changes.Sourcefn state_root_with_updates(
&self,
hashed_state: HashedPostState,
) -> ProviderResult<(B256, TrieUpdates)>
fn state_root_with_updates( &self, hashed_state: HashedPostState, ) -> ProviderResult<(B256, TrieUpdates)>
Returns the state root of the
HashedPostState on top of the current state with trie
updates to be committed to the database.Sourcefn state_root_from_nodes_with_updates(
&self,
input: TrieInput,
) -> ProviderResult<(B256, TrieUpdates)>
fn state_root_from_nodes_with_updates( &self, input: TrieInput, ) -> ProviderResult<(B256, TrieUpdates)>
Returns state root and trie updates.
See [
StateRootProvider::state_root_from_nodes] for more info.Sourceimpl<'a> StorageRootProvider for InstrumentedFinishProvider<'_>
impl<'a> StorageRootProvider for InstrumentedFinishProvider<'_>
Sourcefn storage_root(
&self,
address: Address,
storage: HashedStorage,
) -> ProviderResult<B256>
fn storage_root( &self, address: Address, storage: HashedStorage, ) -> ProviderResult<B256>
Returns the storage root of the
HashedStorage for target address on top of the current
state.Sourcefn storage_proof(
&self,
address: Address,
slot: B256,
storage: HashedStorage,
) -> ProviderResult<StorageProof>
fn storage_proof( &self, address: Address, slot: B256, storage: HashedStorage, ) -> ProviderResult<StorageProof>
Returns the storage proof of the
HashedStorage for target slot on top of the current
state.Sourcefn storage_multiproof(
&self,
address: Address,
slots: &[B256],
storage: HashedStorage,
) -> ProviderResult<StorageMultiProof>
fn storage_multiproof( &self, address: Address, slots: &[B256], storage: HashedStorage, ) -> ProviderResult<StorageMultiProof>
Returns the storage multiproof for target slots.